@@ -85,6 +85,7 @@ docs_bulk.list <- function(x, index = NULL, type = NULL, chunk_size = 1000, raw
   }
   if (is.null(type)) type <- index
   x <- unname(x)
+  x <- check_named_vectors(x)
   rws <- seq_len(length(x))
   chks <- split(rws, ceiling(seq_along(rws) / chunk_size))
   pb <- txtProgressBar(min = 0, max = length(chks), initial = 0, style = 3)
@@ -128,6 +129,16 @@ close_conns <- function() {
   } 
 }
 
+check_named_vectors <- function(x) {
+  lapply(x, function(z) {
+    if (!is(z, "list")) {
+      as.list(z)
+    } else {
+      z
+    }
+  })
+}
+
 # make_bulk_plos(index_name='plosmore', fields=c('id','journal','title','abstract','author'), filename="inst/examples/plos_more_data.json")
 make_bulk_plos <- function(n = 1000, index='plos', type='article', fields=c('id','title'), filename = "~/plos_data.json"){
   unlink(filename)
