@@ -1,8 +1,10 @@
 context("nodes")
 
-invisible(connect())
+invisible(tryCatch(elastic::connect(), error = function(e) e))
 
 test_that("nodes_stats", {
+  skip_on_cran()
+
   out <- nodes_stats()
   out2 <- nodes_stats(node = names(out$nodes))
 
@@ -16,6 +18,8 @@ test_that("nodes_stats", {
 })
 
 test_that("nodes_info", {
+  skip_on_cran()
+
   out <- nodes_info()
   out2 <- nodes_info(node = names(out$nodes))
 
